# Contributing to kiara

## Bug reports and feature requests

kiara uses GitHub Issues for bug reports, feature requests, and support questions.

For confirmed bugs or agreed-upon changes, contributors should create a pull request.

## Any contributions you make will be under the MPL 2.0

See [MPL 2.0](https://www.mozilla.org/en-US/MPL/2.0/).

## Working with kiara

See [kiara documentation](https://docs.kiara.org).
